==> kom%2B%2B-0.2.tar.gz: kom++-0.2/libkom++/comment-order.h <==
// Read texts in comment-order.
//
// $Id: comment-order.h,v 1.3 1994/07/16 17:43:11 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef COMMENT_ORDER__
#define COMMENT_ORDER__

#include <DLList.h>

#include "Local_text_no.SLStack.h"

#include "misc.h"
#include "kom-types.h"
#include "text-mapping.h"

#include "session.h"
#include "read-order.h"

class Conferences;
class Persons;
class Maps;
class Membership;
class Texts;
class get_membership_question;

// 
// This object determines what order the texts should be read
// within a conference.
//

class Comment_order {
  public:
    Comment_order(Session *sess, Conf_no cno, Pers_no reader);
    ~Comment_order();

    // Know about this many texts. This only prefetches the map.
    // Returns number of pending questions, or -1 if an error occurs.
    int       prefetch_map(int texts);

    // Prefetch everything that is normally needed to display the
    // TEXTS first texts. "What is normally needed" is defined as
    // "what is needed by nilkom". Issue at most max_question
    // simultaneous questions. Continue to prefetch everything that
    // can reasonably be prefetched with at least min_question
    // questions thereafter. Return number of pending questions, or -1
    // if an error occurs.
    int	      prefetch(int texts = 5,
		       int max_question = 3,
		       int min_question = 1);

    Prompt    next_prompt();
    Text_no   next_text(Bool remove=FALSE);
    Text_no   next_text_non_comment(Bool remove=FALSE);
    Bool      empty();
    long      min_num_unread();
    long      max_num_unread();
    Conf_no   confno() const;

  private:
    Comment_order(const Comment_order &); // NYI
    const Comment_order & operator = (const Comment_order &);	// NYI

    Session      * session;
    Persons	 & persons;
    Conferences  & conferences;
    Texts	 & texts;
    Text_mapping   map;
    Conf_no        conf_no;
    Pers_no        pers_no;

    get_membership_question *pending_membership_question;
    Membership    *membership;
    void           receive_membership();

    Local_text_no  first_unchecked;
    DLList<Text_no>  unread_texts;
    Local_text_noSLStack pending_footnotes;
    Local_text_noSLStack pending_comments;
    Local_text_noSLStack prefetch_pending_comments;
    int prefetch_ahead;
};
#endif  // COMMENT_ORDER__

==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libkom++/comment-order.h <==
// Read texts in comment-order.
//
// $Id: comment-order.h,v 1.5 1994/07/30 22:14:09 inge Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef COMMENT_ORDER__
#define COMMENT_ORDER__
#if 0
#include <DLList.h>
#include <SLList.h>

#include "misc.h"
#include "kom-types.h"
#include "text-mapping.h"

#include "session.h"
#include "read-order.h"

class Conferences;
class Persons;
class Maps;
class Membership;
class Texts;
class get_membership_question;

// 
// This object determines what order the texts should be read
// within a conference.
//

class Comment_order {
  public:
    Comment_order(Session *sess, Conf_no cno, Pers_no reader);
    ~Comment_order();

    // Know about this many texts. This only prefetches the map.
    // Returns number of pending questions, or -1 if an error occurs.
    int       prefetch_map(int texts);

    // Prefetch everything that is normally needed to display the
    // TEXTS first texts. "What is normally needed" is defined as
    // "what is needed by nilkom". Issue at most max_question
    // simultaneous questions. Continue to prefetch everything that
    // can reasonably be prefetched with at least min_question
    // questions thereafter. Return number of pending questions, or -1
    // if an error occurs.
    int	      prefetch(int texts = 5,
		       int max_question = 3,
		       int min_question = 1);

    Prompt    next_prompt();
    Text_no   next_text(Bool remove=FALSE);
    Text_no   next_text_non_comment(Bool remove=FALSE);
    Bool      empty();
    long      min_num_unread();
    long      max_num_unread();
    Conf_no   confno() const;

  private:
    Comment_order(const Comment_order &); // NYI
    const Comment_order & operator = (const Comment_order &);	// NYI

    Session      * session;
    Persons	 & persons;
    Conferences  & conferences;
    Texts	 & texts;
    Text_mapping   map;
    Conf_no        conf_no;
    Pers_no        pers_no;

    get_membership_question *pending_membership_question;
    Membership    *membership;
    void           receive_membership();

    Local_text_no  first_unchecked;
    DLList<Text_no>  unread_texts;
    SLStack<Local_text_no> pending_footnotes;
    SLStack<Local_text_no> pending_comments;
    SLStack<Local_text_no> prefetch_pending_comments;
    int prefetch_ahead;
};

#endif
#endif  // COMMENT_ORDER__
